# CMeel spirv-tools

[![PyPI version](https://badge.fury.io/py/cmeel-spirv-tools.svg)](https://pypi.org/project/cmeel-spirv-tools)
[![Release](https://github.com/cmake-wheel/cmeel-spirv-tools/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-spirv-tools/actions/workflows/release.yml)

[spirv-tools](https://github.com/KhronosGroup/spirv-tools) distribution for cmeel packages.
